==> healthrian_visualization_support-1.0.36.tar.gz: lib/src/widgets/wear_ecg_12/control_panel_wearecg.dart <==
// ignore_for_file: public_member_api_docs

import 'package:flutter/material.dart';
import 'package:healthrian_ble_support/healthrian_ble_support.dart';

class ControlPanelWearEcg extends StatelessWidget {
  const ControlPanelWearEcg({super.key});

  @override
  Widget build(BuildContext context) {
    return Column(
      mainAxisAlignment: MainAxisAlignment.end,
      crossAxisAlignment: CrossAxisAlignment.end,
      children: [
        FloatingActionButton(
          heroTag: 'ControlPanelWearEcg#1',
          onPressed: () async {
            BLEManager().setEnable(enableList: [true, false, false]);
            await BLEManager().connectDevice();
            await BLEManager().registerCharacteristics();
          },
          child: const Icon(Icons.bluetooth),
        ),
        const SizedBox(height: 8),
        FloatingActionButton(
          heroTag: 'ControlPanelWearEcg#2',
          onPressed: () async {
            BLEManager().setEnable(enableList: [true, false, false]);
            await BLEManager().startMeasurement();
          },
          child: const Icon(Icons.play_arrow),
        ),
        const SizedBox(height: 8),
        FloatingActionButton(
          heroTag: 'ControlPanelWearEcg#3',
          onPressed: () async {
            BLEManager().setEnable(enableList: [true, false, false]);
            await BLEManager().pauseMeasurement();
          },
          child: const Icon(Icons.pause),
        ),
        const SizedBox(height: 8),
        FloatingActionButton(
          heroTag: 'ControlPanelWearEcg#4',
          onPressed: () async {
            BLEManager().setEnable(enableList: [true, false, false]);
            await BLEManager().stopMeasurement();
            await BLEManager().initializeStreams();
          },
          child: const Icon(Icons.stop),
        ),
        const SizedBox(height: 8),
        FloatingActionButton(
          heroTag: 'ControlPanelWearEcg#5',
          onPressed: () {
            BLEManager().setEnable(enableList: [true, false, false]);
            BLEManager().disconnectDevice();
          },
          child: const Icon(Icons.bluetooth_disabled),
        ),
      ],
    );
  }
}

==> healthrian_visualization_support-1.1.7.tar.gz: lib/src/widgets/wear_ecg_12/control_panel_wearecg.dart <==
// ignore_for_file: public_member_api_docs

import 'package:flutter/material.dart';
import 'package:healthrian_ble_support/healthrian_ble_support.dart';

class ControlPanelWearEcg extends StatelessWidget {
  const ControlPanelWearEcg({super.key});

  @override
  Widget build(BuildContext context) {
    return Column(
      mainAxisAlignment: MainAxisAlignment.end,
      crossAxisAlignment: CrossAxisAlignment.end,
      children: [
        FloatingActionButton(
          heroTag: 'ControlPanelWearEcg#1',
          onPressed: () async {
            BLEManager().setMode(enableList: [true, false, false]);
            await BLEManager().connectDevice();
            await BLEManager().registerCharacteristics();
          },
          child: const Icon(Icons.bluetooth),
        ),
        const SizedBox(height: 8),
        FloatingActionButton(
          heroTag: 'ControlPanelWearEcg#2',
          onPressed: () async {
            BLEManager().setMode(enableList: [true, false, false]);
            await BLEManager().startMeasurement();
          },
          child: const Icon(Icons.play_arrow),
        ),
        const SizedBox(height: 8),
        FloatingActionButton(
          heroTag: 'ControlPanelWearEcg#3',
          onPressed: () async {
            BLEManager().setMode(enableList: [true, false, false]);
            await BLEManager().pauseMeasurement();
          },
          child: const Icon(Icons.pause),
        ),
        const SizedBox(height: 8),
        FloatingActionButton(
          heroTag: 'ControlPanelWearEcg#4',
          onPressed: () async {
            BLEManager().setMode(enableList: [true, false, false]);
            await BLEManager().stopMeasurement();
            await BLEManager().initializeStreams();
          },
          child: const Icon(Icons.stop),
        ),
        const SizedBox(height: 8),
        FloatingActionButton(
          heroTag: 'ControlPanelWearEcg#5',
          onPressed: () {
            BLEManager().setMode(enableList: [true, false, false]);
            BLEManager().disconnectDevice();
          },
          child: const Icon(Icons.bluetooth_disabled),
        ),
      ],
    );
  }
}
